@@ -30,11 +30,11 @@ def setup(app):
 
 # -- Project information -----------------------------------------------------
 project = "websocket-client"
-copyright = "2023"
+copyright = "2024"
 author = "liris"
 
 # The full version, including alpha/beta/rc tags
-release = "1.7.0"
+release = "1.8.0"
 
 
 # -- General configuration ---------------------------------------------------
@@ -49,8 +49,13 @@ extensions = [
     "sphinx.ext.viewcode",
     "sphinx.ext.autosectionlabel",
     "sphinx.ext.doctest",
+    "myst_parser",
 ]
 
+# The suffix(es) of source filenames.
+# You can specify multiple suffix as a list of string:
+source_suffix = [".rst", ".md"]
+
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ["_templates"]
 
