@@ -6,10 +6,10 @@ python3 -m venv /tmp/ws-venv/
 source /tmp/ws-venv/bin/activate
 
 # Install dependencies
-pip3 install -U setuptools wheel twine
+pip3 install -U twine
 
 # build the package
-python3 setup.py sdist bdist_wheel
+python -m build
 
 # Run Twine check to verify descriptions are valid
 twine check dist/*
